@@ -10,10 +10,10 @@
  * ----------------- */
 #define UA_OPEN62541_VER_MAJOR 1
 #define UA_OPEN62541_VER_MINOR 3
-#define UA_OPEN62541_VER_PATCH 3
+#define UA_OPEN62541_VER_PATCH 4
 #define UA_OPEN62541_VER_LABEL "" /* Release candidate label, etc. */
-#define UA_OPEN62541_VER_COMMIT "v1.3.3"
-#define UA_OPEN62541_VERSION "v1.3.3"
+#define UA_OPEN62541_VER_COMMIT "v1.3.4"
+#define UA_OPEN62541_VERSION "v1.3.4"
 
 /**
  * Feature Options
@@ -45,10 +45,10 @@
 /* #undef UA_ENABLE_MQTT_TLS */
 /* #undef UA_ENABLE_MQTT_TLS_OPENSSL */
 /* #undef UA_ENABLE_MQTT_TLS_MBEDTLS */
-#define UA_ENABLE_ENCRYPTION_MBEDTLS
+/* #undef UA_ENABLE_ENCRYPTION_MBEDTLS */
 /* #undef UA_ENABLE_TPM2_SECURITY */
 /* #undef UA_ENABLE_ENCRYPTION_OPENSSL */
-/* #undef UA_ENABLE_ENCRYPTION_LIBRESSL */
+#define UA_ENABLE_ENCRYPTION_LIBRESSL
 #if defined(UA_ENABLE_ENCRYPTION_MBEDTLS) || defined(UA_ENABLE_ENCRYPTION_OPENSSL) || defined(UA_ENABLE_ENCRYPTION_LIBRESSL)
 #define UA_ENABLE_ENCRYPTION
 #endif
